@@ -1,31 +1,16 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *   Copyright (C) 2015 by Vyacheslav Matyushin                            *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+    SPDX-FileCopyrightText: 2015 Vyacheslav Matyushin
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "journaldNetworkAnalyzer.h"
 #include "journaldConfiguration.h"
 #include "ksystemlogConfig.h"
+#include "ksystemlog_debug.h"
 #include "logFile.h"
 #include "logViewModel.h"
-#include "logging.h"
 
 #include <QJsonArray>
 #include <QJsonDocument>
@@ -108,8 +93,8 @@ void JournaldNetworkAnalyzer::httpFinished()
         if (!mCursor.isEmpty()) {
             sendRequest(RequestType::EntriesUpdate);
         } else {
-            logWarning() << "Network journal analyzer failed to extract cursor string. "
-                            "Journal updates will be unavailable.";
+            qCWarning(KSYSTEMLOG) << "Network journal analyzer failed to extract cursor string. "
+                                     "Journal updates will be unavailable.";
         }
     } else {
         QString identifiersString = QString::fromUtf8(data);
@@ -158,7 +143,7 @@ void JournaldNetworkAnalyzer::httpError(QNetworkReply::NetworkError code)
     }
 
     updateStatus(i18n("Connection error"));
-    logWarning() << "Network journald connection error:" << code;
+    qCWarning(KSYSTEMLOG) << "Network journald connection error:" << code;
 }
 
 void JournaldNetworkAnalyzer::sslErrors(QNetworkReply *reply, const QList<QSslError> &errors)
@@ -170,7 +155,7 @@ void JournaldNetworkAnalyzer::sslErrors(QNetworkReply *reply, const QList<QSslEr
 void JournaldNetworkAnalyzer::parseEntries(QByteArray &data, Analyzer::ReadingMode readingMode)
 {
     if (mParsingPaused) {
-        logDebug() << "Parsing is paused, discarding journald entries.";
+        qCDebug(KSYSTEMLOG) << "Parsing is paused, discarding journald entries.";
         return;
     }
 
@@ -220,7 +205,7 @@ void JournaldNetworkAnalyzer::parseEntries(QByteArray &data, Analyzer::ReadingMo
     }
 
     if (entries.empty()) {
-        logDebug() << "Received no entries.";
+        qCDebug(KSYSTEMLOG) << "Received no entries.";
     } else {
         mInsertionLocking.lock();
         mLogViewModel->startingMultipleInsertions();
@@ -283,11 +268,11 @@ void JournaldNetworkAnalyzer::sendRequest(RequestType requestType)
     }
 
     request.setUrl(QUrl(url));
-    logDebug() << "Journal network analyzer requested" << url;
+    qCDebug(KSYSTEMLOG) << "Journal network analyzer requested" << url;
     mReply = mNetworkManager.get(request);
     connect(mReply, &QNetworkReply::finished, this, &JournaldNetworkAnalyzer::httpFinished);
     connect(mReply, &QNetworkReply::readyRead, this, &JournaldNetworkAnalyzer::httpReadyRead);
-    connect(mReply, QOverload<QNetworkReply::NetworkError>::of(&QNetworkReply::errorOccurred), this, &JournaldNetworkAnalyzer::httpError);
+    connect(mReply, qOverload<QNetworkReply::NetworkError>(&QNetworkReply::errorOccurred), this, &JournaldNetworkAnalyzer::httpError);
 }
 
 void JournaldNetworkAnalyzer::updateStatus(const QString &status)
